@@ -22,7 +22,6 @@
 #ifndef GST_DIALOG_H
 #define GST_DIALOG_H
 
-#include <libgnomeui/gnome-app.h>
 #include <glade/glade.h>
 #include "gst-types.h"
 #include "gst-tool.h"
@@ -47,7 +46,7 @@ struct _GstDialogSignal {
 };
 
 struct _GstDialog {
-	GnomeApp app;
+	GtkDialog dialog;
 	GstTool *tool;
 
 	/* Glade files */
@@ -64,14 +63,10 @@ struct _GstDialog {
 };
 
 struct _GstDialogClass {
-	GnomeAppClass parent_class;
-
-	void (*apply)             (GstDialog *);
-	void (*restore)           (GstDialog *);
-	void (*complexity_change) (GstDialog *);
+	GtkDialogClass parent_class;
 };
 
-GtkType             gst_dialog_get_type            (void);
+GType               gst_dialog_get_type            (void);
 
 GstDialog          *gst_dialog_new                 (GstTool *tool, 
 						    const char *widget, 
